@@ -116,7 +116,7 @@ KGameDebugDialog::KGameDebugDialog(KGame* g, QWidget* parent, bool modal)
     : KPageDialog(parent),
       d( new KGameDebugDialogPrivate )
 {
- setWindowTitle(i18n("KGame Debug Dialog"));
+ setWindowTitle(i18nc("@title:window", "KGame Debug Dialog"));
  //QT5 setButtons(Close);
  //QT5 setDefaultButton(Close);
  setModal(modal);
@@ -194,8 +194,8 @@ void KGameDebugDialog::initPlayerPage()
  QLabel* listLabel = new QLabel(i18n("Available Players"), d->mPlayerPage);
  listLayout->addWidget(listLabel);
  d->mPlayerList = new QListWidget(d->mPlayerPage);
- connect(d->mPlayerList, &QListWidget::itemActivated,
-         this, QOverload<QListWidgetItem*>::of(&KGameDebugDialog::slotUpdatePlayerData));
+ connect(d->mPlayerList, &QListWidget::itemActivated, this,
+         qOverload<QListWidgetItem *>(&KGameDebugDialog::slotUpdatePlayerData));
  listLayout->addWidget(d->mPlayerList);
  d->mPlayerList->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding));
 
